# The ctpcrunch package

The ctpcrunch package is a collection of Python utilities to help understand and develop phase cycles for selecting coherence order transfer paths.

## What is a CTP?

A coherence order transfer path (CTP) describes what quantum mechanical coherence orders are present in a nuclear magnetic resonance experiment at a given point in time.


## Quickstart

## Generating and using a CTP object

```python
import ctpcrunch as cc

myctp = cc.CTP(3)

```

## Examples

### Finding the first cogwheel phase cycle

### Heteronuclear Experiment: INEPT


## Todos

- Get done.